This function reads multiple acoustic file to a list with a list of tables for each file.
ReadAcoustic(FileNames = character())An object of StoX data type AcousticData: A list of a list of data.tables of the different levels of the input acoustic files.
The file is read using the ICESAcoustic XSD defined by ICES acoustic database (https://www.ices.dk/data/data-portals/Pages/acoustic.aspx), with additional information about headers defined by the internal function icesAcousticPreprocess.
One particular case is when headers (e.g. LocalID) are stored as NA in the file. This results in the string "NA" and not the missing value NA. To read fields as NA, the field must be left out in the file.
exampleFile <- system.file(
"testresources","libas_ListUserFile20__L40.0-2259.9_small.xml", package="RstoxData")
acousticData <- ReadAcoustic(exampleFile)