Order a data.table (by reference) by interpreting characters as numeric if possible

setorderv_numeric(
  dataOne,
  by = NULL,
  key = NULL,
  split = "/",
  colsToSplit = NA
)

Arguments

dataOne

A data.table.

by

Order by the given columns.

key

If given and by is empty, order by the columns with names ending with key.

split

Character: A vector of single character to split by. The default c("-", "/") splits between StoX keys and within StoX keys.

colsToSplit

Character: A vector of the columns to apply splitting in in createOrderKey, or NA (default) to potentially split all columns specified by by.