R/Utilities.R
createOrderKey.Rd
Convert a vector to an integer vector where individual string elements are interpreted as numeric if possible.
createOrderKey(x, split = "/", doNotSplit = FALSE)
A vector.
A character to split strings by.
Logical: If TRUE to not split the input to treat the parts as potential numeric values, but merely treat the input as numeri if possible.