Informative match.arg
match_arg_informative(
arg,
choices,
several.ok = FALSE,
arg_name = substitute(arg),
ignore.case = FALSE
)a character vector (of length one unless several.ok
is TRUE) or NULL which means to take choices[1].
a character vector of candidate values, often missing, see ‘Details’.
either a logical specifying if arg
should be allowed to have more than one element or a string, starting
with "all" meaning that arg may have more than one
element all of which must match choices.
The name of the argument, interpreted by default.
Logical: Should case be igngored.